@@ -1,6 +1,6 @@
 import numpy as np
 
-__all__ = ['permute']
+__all__ = ["permute"]
 
 
 def permute(a):
@@ -10,7 +10,7 @@ def permute(a):
     TCHS Computer Information Systems.  My thanks to him.
     """
 
-    a.sort() # Sort.
+    a.sort()  # Sort.
 
     ## Output the first input sorted.
     yield list(a)
@@ -21,28 +21,29 @@ def permute(a):
 
     ## "alen" could also be used for the reference to the last element.
 
-    while(True):
+    while True:
         i = alen - 1
 
-        while(True):
-            i -= 1 # i--
+        while True:
+            i -= 1  # i--
 
-            if(a[i] < a[(i + 1)]):
+            if a[i] < a[(i + 1)]:
                 j = alen - 1
 
-                while(not (a[i] < a[j])): j -= 1 # j--
+                while not (a[i] < a[j]):
+                    j -= 1  # j--
 
-                a[i], a[j] = a[j], a[i] # swap(a[j], a[i])
-                t = a[(i + 1):alen]
+                a[i], a[j] = a[j], a[i]  # swap(a[j], a[i])
+                t = a[(i + 1) : alen]
                 t.reverse()
-                a[(i + 1):alen] = t
+                a[(i + 1) : alen] = t
 
                 # Output current.
                 yield list(a)
 
-                break # next.
+                break  # next.
 
-            if(i == first):
+            if i == first:
                 a.reverse()
 
                 # yield list(a)
